==> aws-java-sdk-redshift-1.11.60-sources.jar: com/amazonaws/services/redshift/model/transform/DescribeTableRestoreStatusResultStaxUnmarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.redshift.model.transform;

import java.util.Map;
import java.util.HashMap;
import java.util.ArrayList;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.redshift.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * DescribeTableRestoreStatusResult StAX Unmarshaller
 */
public class DescribeTableRestoreStatusResultStaxUnmarshaller implements Unmarshaller<DescribeTableRestoreStatusResult, StaxUnmarshallerContext> {

    public DescribeTableRestoreStatusResult unmarshall(StaxUnmarshallerContext context) throws Exception {
        DescribeTableRestoreStatusResult describeTableRestoreStatusResult = new DescribeTableRestoreStatusResult();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument())
            targetDepth += 2;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument())
                return describeTableRestoreStatusResult;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {

                if (context.testExpression("TableRestoreStatusDetails/TableRestoreStatus", targetDepth)) {
                    describeTableRestoreStatusResult.withTableRestoreStatusDetails(TableRestoreStatusStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }

                if (context.testExpression("Marker", targetDepth)) {
                    describeTableRestoreStatusResult.setMarker(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return describeTableRestoreStatusResult;
                }
            }
        }
    }

    private static DescribeTableRestoreStatusResultStaxUnmarshaller instance;

    public static DescribeTableRestoreStatusResultStaxUnmarshaller getInstance() {
        if (instance == null)
            instance = new DescribeTableRestoreStatusResultStaxUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-redshift-1.11.70-sources.jar: com/amazonaws/services/redshift/model/transform/DescribeTableRestoreStatusResultStaxUnmarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.redshift.model.transform;

import java.util.Map;
import java.util.HashMap;
import java.util.ArrayList;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.redshift.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * DescribeTableRestoreStatusResult StAX Unmarshaller
 */
public class DescribeTableRestoreStatusResultStaxUnmarshaller implements Unmarshaller<DescribeTableRestoreStatusResult, StaxUnmarshallerContext> {

    public DescribeTableRestoreStatusResult unmarshall(StaxUnmarshallerContext context) throws Exception {
        DescribeTableRestoreStatusResult describeTableRestoreStatusResult = new DescribeTableRestoreStatusResult();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument())
            targetDepth += 2;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument())
                return describeTableRestoreStatusResult;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {

                if (context.testExpression("TableRestoreStatusDetails", targetDepth)) {
                    describeTableRestoreStatusResult.withTableRestoreStatusDetails(new ArrayList<TableRestoreStatus>());
                    continue;
                }

                if (context.testExpression("TableRestoreStatusDetails/TableRestoreStatus", targetDepth)) {
                    describeTableRestoreStatusResult.withTableRestoreStatusDetails(TableRestoreStatusStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }

                if (context.testExpression("Marker", targetDepth)) {
                    describeTableRestoreStatusResult.setMarker(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return describeTableRestoreStatusResult;
                }
            }
        }
    }

    private static DescribeTableRestoreStatusResultStaxUnmarshaller instance;

    public static DescribeTableRestoreStatusResultStaxUnmarshaller getInstance() {
        if (instance == null)
            instance = new DescribeTableRestoreStatusResultStaxUnmarshaller();
        return instance;
    }
}
